$set 14 #main

$ #RCRequiresArg
# Erreur: '-rc' ncessite un argument\n
$ #MENURequiresArg
# Erreur: '-menu' ncessite un argument\n
$ #DISPLAYRequiresArg
# Erreur: '-display' ncessite un argument\n
$ #WarnDisplaySet
# Attention: impossible d'attribuer la variable d'environnement 'DISPLAY'\n
$ #Usage
# Openbox %s: (c) 2002 - 2002 Ben Jansens\n\
  \t\t\t  2001 - 2002 Sean 'Shaleh' Perry\n\
  \t\t\t  1997 - 2000 Brad Hughes\n\n\
  -display <chane>\t\tutilise la connexion  l'affichage.\n\
  -rc <chane>\t\t\tutilise un autre fichier de configuration.\n\
  -menu <chane>\t\t\tutilise un autre fichier de menu.\n\
  -version\t\t\taffiche la version et quitte.\n\
  -help\t\t\t\taffiche ce texte d'aide et quitte.\n\n
$ #CompileOptions
# Options de compilation:\n\
  Debugging\t\t\t%s\n\
  Interlacing:\t\t\t%s\n\
  Shape:\t\t\t%s\n\
  Slit:\t\t\t\t%s\n\
  8bpp Ordered Dithering:\t%s\n\
  Event Clobbering:\t\t%s\n\n
